@@ -27,13 +27,19 @@ describe 'trove::taskmanager' do
 
       let :pre_condition do
         "class { 'trove':
-         nova_proxy_admin_pass     => 'verysecrete',
-         os_region_name            => 'RegionOne',
-         nova_compute_service_type => 'compute',
-         cinder_service_type       => 'volume',
-         swift_service_type        => 'object-store',
-         heat_service_type         => 'orchestration',
-         neutron_service_type      => 'network'}"
+         nova_proxy_admin_pass      => 'verysecrete',
+         os_region_name             => 'RegionOne',
+         nova_compute_service_type  => 'compute',
+         cinder_service_type        => 'volume',
+         swift_service_type         => 'object-store',
+         neutron_service_type       => 'network',
+         nova_compute_endpoint_type => '<SERVICE DEFAULT>',
+         cinder_endpoint_type       => '<SERVICE DEFAULT>',
+         swift_endpoint_type        => '<SERVICE DEFAULT>',
+         trove_endpoint_type        => '<SERVICE DEFAULT>',
+         glance_endpoint_type       => '<SERVICE DEFAULT>',
+         neutron_endpoint_type      => '<SERVICE DEFAULT>',
+         }"
       end
 
       it 'installs trove-taskmanager package and service' do
@@ -59,8 +65,13 @@ describe 'trove::taskmanager' do
         is_expected.to contain_trove_taskmanager_config('DEFAULT/nova_compute_service_type').with_value('compute')
         is_expected.to contain_trove_taskmanager_config('DEFAULT/cinder_service_type').with_value('volume')
         is_expected.to contain_trove_taskmanager_config('DEFAULT/swift_service_type').with_value('object-store')
-        is_expected.to contain_trove_taskmanager_config('DEFAULT/heat_service_type').with_value('orchestration')
         is_expected.to contain_trove_taskmanager_config('DEFAULT/neutron_service_type').with_value('network')
+        is_expected.to contain_trove_taskmanager_config('DEFAULT/nova_compute_endpoint_type').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_taskmanager_config('DEFAULT/cinder_endpoint_type').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_taskmanager_config('DEFAULT/swift_endpoint_type').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_taskmanager_config('DEFAULT/trove_endpoint_type').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_taskmanager_config('DEFAULT/neutron_endpoint_type').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_taskmanager_config('DEFAULT/glance_endpoint_type').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_taskmanager_config('DEFAULT/taskmanager_manager').with_value('trove.taskmanager.manager.Manager')
         is_expected.to contain_file('/etc/trove/trove-guestagent.conf')
         is_expected.to contain_trove_taskmanager_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>')
@@ -75,6 +86,7 @@ describe 'trove::taskmanager' do
         is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/rabbit_userid').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/rabbit_password').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/kombu_failover_strategy').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_oslo__messaging__rabbit('trove_taskmanager_config').with(
           :rabbit_use_ssl => '<SERVICE DEFAULT>',
